# Man delete

> delete [subject] - In shell mode, delete a conversation under the subject name. If not subject it is passed, it will delete the current conversation based on its subject name.

## Usage

`delete`

`delete game002`